package com.lowagie.test.functional.pdf;

import com.lowagie.text.*;
import com.lowagie.text.Font;
import com.lowagie.text.Rectangle;
import com.lowagie.text.pdf.PdfWriter;
import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.PdfContentByte;
import com.lowagie.text.pdf.ColumnText;

import java.io.IOException;
import java.io.OutputStream;
import java.awt.*;

public class ColumnTextTestSuite extends PdfBaseTestSuite {
    private String description = "Tests ColumnText";

    public ColumnTextTestSuite() {
    }

    public ColumnTextTestSuite(OutputStream os) throws DocumentException {
        super(PageSize.LETTER);
    }

    public void testSimpleText() throws BadElementException, DocumentException, IOException {
       document.newPage();
       Font font = FontFactory.getFont("Helvetica", 8, Font.BOLD, Color.BLACK);
       PdfContentByte cb = writer.getDirectContentUnder();
       ColumnText testText = new ColumnText(cb);
       testText.setUseAscender(true);

       //addText("\n\nThis test uses setUseAscent(true) using addText", Element.ALIGN_MIDDLE);


       float llx, lly, urx, ury;
       float testWidth = 100f;
       float testHeight = 100f;
       llx = document.leftMargin();
       ury = document.top() - 100f;
       urx = llx + testWidth;
       lly = ury - testHeight;

       // start irregular
       float diamondHeight = 400;
       float diamondWidth = 400;
       float gutter = 10;
       float bodyHeight = document.top() - document.bottom();
       float colMaxWidth = (document.right() - document.left() - (gutter * 2)) / 2f;
       float diamondTop = document.top() - ((bodyHeight - diamondHeight) / 2f);
       float diamondInset = colMaxWidth - (diamondWidth / 2f);


       float[] left = {document.left(), document.top(), document.left(), document.bottom()};
       float[] right = {document.left() + colMaxWidth, document.top(),
                        document.left() + colMaxWidth, diamondTop,
                        document.left() + diamondInset, diamondTop - diamondHeight / 2,
                        document.left() + colMaxWidth, diamondTop - diamondHeight,
                        document.left() + colMaxWidth, document.bottom() };
       testText.setYLine(document.top());
       testText.setColumns(left, right);

       // end irregular



       //testText.setSimpleColumn(llx, lly, urx, ury);
       testText.addText(new Phrase("Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nullam placerat aliquam leo. Morbi mauris tellus, vulputate nec, feugiat sit amet, eleifend vel, mauris. Nullam augue. Duis tristique. Sed condimentum suscipit risus. Quisque nec orci eu pede tincidunt bibendum. Integer ligula dolor, euismod quis, posuere a, viverra sit amet, augue. Praesent id eros. Mauris id tellus ac sem pharetra dapibus. In hac habitasse platea dictumst. Maecenas aliquam, ante non pulvinar ultricies, felis nunc porta nisl, vel molestie ipsum mauris non tortor. Suspendisse volutpat. Aliquam eros. Praesent fermentum. Maecenas a lectus vel mauris rhoncus lobortis. Curabitur quis risus at magna tempus malesuada. Sed posuere tortor in nulla. Mauris nibh velit, accumsan sed, pellentesque vel, interdum a, lacus. Sed a magna.", font));
       testText.addText(new Phrase("Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nullam placerat aliquam leo. Morbi mauris tellus, vulputate nec, feugiat sit amet, eleifend vel, mauris. Nullam augue. Duis tristique. Sed condimentum suscipit risus. Quisque nec orci eu pede tincidunt bibendum. Integer ligula dolor, euismod quis, posuere a, viverra sit amet, augue. Praesent id eros. Mauris id tellus ac sem pharetra dapibus. In hac habitasse platea dictumst. Maecenas aliquam, ante non pulvinar ultricies, felis nunc porta nisl, vel molestie ipsum mauris non tortor. Suspendisse volutpat. Aliquam eros. Praesent fermentum. Maecenas a lectus vel mauris rhoncus lobortis. Curabitur quis risus at magna tempus malesuada. Sed posuere tortor in nulla. Mauris nibh velit, accumsan sed, pellentesque vel, interdum a, lacus. Sed a magna.", font));
       //testText.addText(new Phrase("This is even more stuff.", font));
       testText.go();
       /*
       float rulerHeight = document.getPageSize().height() - document.topMargin();
       addRuler(1f, llx - 10, rulerHeight, rulerHeight);
       cb.setColorStroke(Color.BLACK);
       cb.setLineWidth(0.5f);
       cb.moveTo(llx, ury);
       cb.lineTo(urx, ury);
       cb.stroke();
       */
    }

   public void testCompositeText() throws BadElementException, DocumentException, IOException {
      document.newPage();
      Font font = FontFactory.getFont("Helvetica", 8, Font.BOLD, Color.BLACK);
      PdfContentByte cb = writer.getDirectContentUnder();
      ColumnText testText = new ColumnText(cb);
      testText.setUseAscender(true);

      addText("\n\nThis test uses setUseAscent(true) using addElement", Element.ALIGN_MIDDLE);

      float llx, lly, urx, ury;
      float testWidth = 100f;
      float testHeight = 100f;
      llx = document.leftMargin();
      ury = document.getPageSize().height() - document.topMargin() - 100f;
      urx = llx + testWidth;
      lly = ury - testHeight;

      testText.setSimpleColumn(llx, lly, urx, ury);
      testText.addElement(new Paragraph("This is a test phrase to see how this wraps.  This even\nhas\nline breaks.", font));
      testText.go();
      float rulerHeight = document.getPageSize().height() - document.topMargin();
      addRuler(1f, llx - 10, rulerHeight, rulerHeight);
      cb.setColorStroke(Color.BLACK);
      cb.setLineWidth(0.5f);
      cb.moveTo(llx, ury);
      cb.lineTo(urx, ury);
      cb.stroke();
   }


}
