package com.lowagie.test.functional.pdf;

import com.lowagie.text.*;
import com.lowagie.text.Font;
import com.lowagie.text.Rectangle;
import com.lowagie.text.pdf.*;

import java.io.IOException;
import java.io.OutputStream;
import java.awt.*;
import java.util.Random;

public class MultiColumnTextTestSuite extends PdfBaseTestSuite {
    private String description = "Tests MultiColumnText";
    Random rand = new Random(0L);

    public MultiColumnTextTestSuite() {
        pageSize = PageSize.LETTER;
    }

    public MultiColumnTextTestSuite(OutputStream os) throws DocumentException {
        super(PageSize.LETTER);
    }

    public void test3Column2PageAutomatic() throws DocumentException{
       document.newPage();
       addText("Page Fill Test", Element.ALIGN_CENTER, Font.BOLD);
       addText("3 Columns, AUTOMATIC height", Element.ALIGN_CENTER);
       runTest(30, 3, MultiColumnText.AUTOMATIC);
    }

   public void test4Column2PageAutomatic() throws DocumentException{
       document.newPage();
      addText("Page Fill Test", Element.ALIGN_CENTER, Font.BOLD);
      addText("4 Columns, AUTOMATIC height", Element.ALIGN_CENTER);
      runTest(30, 4, MultiColumnText.AUTOMATIC);
   }


    public void testFixedHeight() throws DocumentException
    {
       document.newPage();
       float ypos =document.top();
       drawHorizontalLine(ypos);

       addText("Fixed height Test", Element.ALIGN_CENTER, Font.BOLD);
       ypos -= 12f;
       drawHorizontalLine(ypos);

       addText("3 Columns, fixed height 300", Element.ALIGN_CENTER);
       ypos -= 12f;
       drawHorizontalLine(ypos);

       ypos -= 12f;
       drawHorizontalLine(ypos);

       runTest(10, 3, 300f);
       ypos -= 300f;
       drawHorizontalLine(ypos);
       addText("This should be right after the columns", Element.ALIGN_LEFT);
       float rulerTop = document.getPageSize().top();
       addRuler(1f, document.leftMargin() - 10, rulerTop, rulerTop);
    }


   public void testFixedHeightOverPage() throws DocumentException
   {
      document.newPage();
      float ypos =document.top();
      drawHorizontalLine(ypos);

      addText("Fixed height Test", Element.ALIGN_CENTER, Font.BOLD);
      addText("3 Columns, fixed height 300", Element.ALIGN_CENTER);

      addText("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"+
              "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", Element.ALIGN_CENTER);
      ypos -= (43 * 12);
      drawHorizontalLine(ypos);

      float page1part = ypos - document.bottom();
      runTest(10, 3, 300f);
      ypos = document.top() - (300 - page1part);
      drawHorizontalLine(ypos);

      addText("This should be right after the columns", Element.ALIGN_LEFT);
      float rulerTop = document.getPageSize().top();
      addRuler(1f, document.leftMargin() - 10, rulerTop, rulerTop);
   }

    private void runTest(int numPoems, int numColumns, float height) throws DocumentException
    {
       MultiColumnText mct = new MultiColumnText(height);
       mct.addRegularColumns(document.left(), document.right(), 10f, numColumns);

       for (int i=0; i<numPoems; i++) {
          mct.addElement(newPara(randomWord(noun), Element.ALIGN_CENTER, Font.BOLDITALIC));
          for (int j=0; j<4; j++ ) {
             mct.addElement(newPara(poemLine(), Element.ALIGN_LEFT, Font.NORMAL));
          }
          mct.addElement(newPara(randomWord(adverb), Element.ALIGN_LEFT, Font.NORMAL));
          mct.addElement(newPara("\n\n", Element.ALIGN_LEFT, Font.NORMAL));
       }

       document.add(mct);
    }

    private Element newPara(String text, int alignment, int type) {
       Font font = FontFactory.getFont("Helvetica", 10, type, Color.BLACK);
       Paragraph p = new Paragraph(text, font);
       p.setAlignment(alignment);
       p.setLeading(font.size() * 1.2f);
       return p;
    }

   String[] verb = {"flows", "draws", "renders", "throws exception", "runs",
	   "crashes", "downloads", "usurps", "vexes", "whispers", "boils",
	   "capitulates", "crashes", "craves", "looks", "defies", "defers",
	   "defines", "envelops", "entombs", "falls", "fails", "halts",
	   "appears", "nags", "overflows", "burns", "dies", "writes",
	   "flushes"};

   String[] noun = {"ColumnText", "paragraph", "phrase", "chunk", "PdfContentByte",
	   "PdfPTable", "iText", "color", "vertical alignment", "horizontal alignment", "PdfWriter",
	   "ListItem", "PdfStamper", "PDF", "HTML", "XML", "column", "font",
	   "table", "FDF", "field", "NullPointerException", "CJK font"};

   String[] adjective = {"foul", "broken", "gray", "slow", "beautiful",
	  "throbbing", "sharp", "stout", "soundless", "neat",
	  "swift", "uniform", "upright", "vibrant", "dingy",
	  "vestigal", "messy", "sloppy", "baleful", "boastful",
	  "dark", "capricious", "concrete", "deliberate", "sharp",
	   "drunken", "undisciplined", "perfect", "bloated"};

   String[] adverb = {"randomly", "quickly", "triumphantly", "suggestively",
	  "slowly", "angrily", "uncomfortably", "finally", "unexpectedly",
	  "hysterically", "thinly", "dryly", "blazingly",
	  "terribly", "bleakly", "irritably", "dazzlingly", "expectantly",
	  "impersonally", "abruptly", "awfully", "caressingly", "completely",
	  "undesirably", "drolly", "hypocritically", "blankly",
	  "dimly"};

   /*
   static String[] verb = {"exhales", "sucks", "smotes", "sheds", "stoops",
	   "sullies", "shrieks", "usurps", "vexes", "whispers", "boils",
	   "capitulates", "crashes", "craves", "looks", "defies", "defers",
	   "defines", "envelops", "entombs", "falls", "sighs", "languishes",
	   "mars", "nags", "overflows", "burns", "dies", "concocts",
	   "nourishes"};

   static String[] noun = {"feces", "body", "coma", "rider", "sack", "sheep",
	   "party", "summer", "vein", "vessel", "vowel", "vortex",
	   "laundromat", "dream", "agitation", "battle-axe", "chivalry",
	   "condescension", "concubine", "corduroy", "creationism",
	   "degeneration", "street", "entry", "enticement", "language",
	   "life", "light", "dope", "nothing"};

   static String[] adjective = {"foul", "broken", "gray", "ignominious", "plastic",
	  "throbbing", "sharp", "stout", "soundless", "traveled",
	  "tribal", "uniform", "unhoped", "upright", "vibrant",
	  "vestigal", "aggressive", "agnostic", "baleful", "boastful",
	  "dark", "capricious", "concrete", "deliberate", "narcissistic",
	  "dingy", "drunken", "undisciplined", "perfect", "perforated"};

   static String[] adverb = {"grimly", "unholily", "triumphantly", "suggestively",
		"immortally",
	  "sleeplessly", "angrily", "uncomfortably", "finally", "balmily",
	  "hysterically", "thinly", "dryly", "perfunctorily",
	  "terribly", "bleakly", "irritably", "dazzlingly", "expectantly",
	  "impersonally", "abruptly", "awfully", "caressingly", "completely",
	  "undesirably", "drolly", "hypocritically", "blankly",
	  "dimly"};
   */
   private String randomWord(String[] type)
   {
      return type[rand.nextInt(type.length)];
   }

   public String poemLine()
   {
      StringBuffer results = new StringBuffer(150);
      results.append(randomWord(adjective));
      results.append(" ");
      results.append(randomWord(noun));
      results.append(" ");
      results.append(randomWord(verb));
      results.append(" ");
      results.append(randomWord(adverb));
      results.append(", ");
      return results.toString();
}

}
