package com.lowagie.test.functional.pdf;

import com.lowagie.text.*;
import com.lowagie.text.Font;
import com.lowagie.text.Rectangle;
import com.lowagie.text.Image;
import com.lowagie.text.pdf.*;

import java.io.IOException;
import java.io.OutputStream;
import java.awt.*;

public class NestedPdfPTableTestSuite extends PdfBaseTestSuite {
    private String description = "Tests nested com.lowagie.text.pdf.PdfPTables";


   public NestedPdfPTableTestSuite() {
    }

    public NestedPdfPTableTestSuite(OutputStream os) throws DocumentException {
        super(PageSize.LETTER);
    }


    public void testSimpleNesting() throws DocumentException
    {
        document.newPage();
        Font tableFont = FontFactory.getFont("Helvetica", 8, Font.BOLD, Color.BLACK);
        PdfPTable outerTable = new PdfPTable(1);
        outerTable.setWidthPercentage(100);
        Paragraph p = new Paragraph("test", tableFont);

        PdfPTable innerTable= new PdfPTable(1);
        innerTable.setWidthPercentage(100);
        innerTable.addCell(makeCell(new Element[] {p }, Element.ALIGN_LEFT, Element.ALIGN_TOP));

        outerTable.addCell(makeCell(new Element[] {p, innerTable}, Element.ALIGN_LEFT, Element.ALIGN_TOP));
        document.add(outerTable);
    }

    public void testMultipleNesting() throws DocumentException  {
        try {
        document.newPage();
        Font tableFont = FontFactory.getFont("Helvetica", 8, Font.BOLD, Color.BLACK);
        PdfPTable outerTable = new PdfPTable(1);
        outerTable.setWidthPercentage(100f);
        Paragraph p = new Paragraph("test", tableFont);

        // If the widths on these two tables aren't the same, it will
        //   cause an ArrayIndexOutOfBoundsException at Table.mergeInsertedTables(Table.java:1437)
        //   as of iText-paulo-138
        PdfPTable innerTable1= new PdfPTable(1);
        innerTable1.setWidthPercentage(90f);
        innerTable1.addCell(makeCell(new Element[] {p }, Element.ALIGN_LEFT, Element.ALIGN_TOP));

        PdfPTable innerTable2= new PdfPTable(1);
        innerTable2.setWidthPercentage(90.1f);
       innerTable2.addCell(makeCell(new Element[] {p }, Element.ALIGN_LEFT, Element.ALIGN_TOP));


        outerTable.addCell(makeCell(new Element[] {innerTable1}, Element.ALIGN_LEFT, Element.ALIGN_TOP));
        outerTable.addCell(makeCell(new Element[] {innerTable2 }, Element.ALIGN_LEFT, Element.ALIGN_TOP));

        document.add(outerTable);
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }
/*
   public void testImageNesting() throws DocumentException
   {
     document.newPage();
      PdfPTable outerTable = new PdfPTable(1);
      outerTable.setWidthPercentage(0.8f / 8.5f);

      PdfPTable innerTable = new PdfPTable(1);
      innerTable.setWidthPercentage(100f);

      Image cellImage = null;

      String imagePath = "file:/C:/Working/ALC/WEBCTRL3_0/webroot/_common/lvl5/graphics/main/color_graphics/coral.gif";
      try
      {
         cellImage = Image.getInstance(imagePath);
         cellImage.scaleAbsoluteWidth(12);
         cellImage.scaleAbsoluteHeight(12);
      } catch (IOException e)

      {
         e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
         return;
      }
      PdfPCell cell = new PdfPCell(cellImage, false);
      cell.setHorizontalAlignment(Element.ALIGN_CENTER);
      cell.setVerticalAlignment(Element.ALIGN_TOP);
      cell.setUseAscender(true);
      cell.setUseDescender(true);
      cell.setUseBorderPadding(true);

      innerTable.addCell(cell);

      PdfPCell tableCell = new PdfPCell();
      tableCell.addElement(innerTable);
      tableCell.setHorizontalAlignment(Element.ALIGN_CENTER);
      tableCell.setVerticalAlignment(Element.ALIGN_TOP);

      //outerTable.addCell(tableCell);
      document.add(innerTable);
   }
*/

    PdfPCell makeCell(Element[] elements, int hAlign, int vAlign)  {
        PdfPCell cell = new PdfPCell();
        cell.setHorizontalAlignment(hAlign);
        cell.setVerticalAlignment(vAlign);
        if (elements != null) {
            for (int i = 0; i < elements.length; i++) {
                Element el = elements[i];
                cell.addElement(el);
            }
        }
        return cell;
    }

}
