package com.lowagie.test.functional.pdf;

import com.lowagie.text.pdf.PdfWriter;
import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.PdfContentByte;
import com.lowagie.text.*;
import com.lowagie.text.Rectangle;
import com.lowagie.text.Font;
import com.lowagie.text.xml.XmlWriter;
import com.lowagie.test.functional.FunctionalTestSuite;

import java.io.IOException;
import java.io.OutputStream;
import java.awt.*;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

public abstract class PdfBaseTestSuite extends FunctionalTestSuite {

    protected PdfWriter writer;

    PdfBaseTestSuite() {
        pageSize = PageSize.LETTER;
    }


    PdfBaseTestSuite(Rectangle pageSize) throws DocumentException {
        this.pageSize = pageSize;
    }

    public void startTesting(OutputStream os) throws DocumentException{
        if (document == null) {
            document = new Document(pageSize);
            writer = PdfWriter.getInstance(document, os);
            document.open();
        }
    }


    public void stopTesting() {
        if (document != null) {
            document.close();
            if (writer != null) {
                writer.flush();
                writer.close();
            }
            document = null;
            writer = null;
        }
    }

    public void startDebugging(OutputStream os) throws Exception {
        if (document == null) {
            document = new Document(pageSize);
            debugWriter = XmlWriter.getInstance(document, os);
            document.open();
        }
    }





    public void addRuler(float tickInterval, float startx, float starty, float length) throws DocumentException
    {
        if (writer != null) {
           Font font = FontFactory.getFont("Helvetica", 10, Font.NORMAL, Color.BLACK);
           BaseFont bf = font.getBaseFont();
           PdfContentByte grx = writer.getDirectContent();
           float smallTick = 2.0f;
           grx.setLineWidth(0.1f);
           grx.setColorStroke(new Color(120,120,120));
           grx.setColorFill(new Color(120,120,120));
           float y = Math.round(starty);
           int i=0;
           while (y > starty - length)
           {
              float tickLength;
              if (y % 10 == 0)
              {
                 tickLength = smallTick * 4f;
              }
              else if (y % 5 == 0)
              {
                 tickLength = smallTick * 2f;
              }
              else
              {
                 tickLength = smallTick;
              }

              grx.moveTo(startx, y);
              grx.lineTo(startx + tickLength, y);
              grx.stroke();

              if (y % 50 == 0)
              {
                 grx.beginText();
                 grx.setFontAndSize(bf, 6);
                 grx.setTextMatrix(startx - 12, y-2.5f);
                 grx.showText(Integer.toString((int)y));
                 grx.endText();
              }
              y -= tickInterval;
              i++;
           }
        }
    }

    public void drawTarget(float x, float y, float size)
    {
        if (writer != null) {
            PdfContentByte cb = writer.getDirectContent();
            cb.setColorStroke(Color.RED);
            cb.setLineWidth(0.2f);
            cb.moveTo(x - (size/2),y);
            cb.lineTo(x + (size/2), y);
            cb.stroke();
            cb.moveTo(x, y+(size/2));
            cb.lineTo(x, y-(size/2));
            cb.stroke();
        }
    }

    public void drawHorizontalLine(float ypos)
    {
        if (writer != null) {
           PdfContentByte cb = writer.getDirectContent();
           cb.setColorStroke(Color.BLACK);
           cb.setLineWidth(0.2f);
           cb.moveTo(document.left(), ypos);
           cb.lineTo(document.right(), ypos);
           cb.stroke();
        }
    }

    public void addText(String text, int alignment) throws DocumentException {
       addText(text, alignment, Font.NORMAL);
    }

   public void addText(String text, int alignment, int type) throws DocumentException {
      Font font = FontFactory.getFont("Helvetica", 10, type, Color.BLACK);
      Paragraph p = new Paragraph(text, font);
      p.setAlignment(alignment);
      p.setLeading(font.size() * 1.2f);
      document.add(p);
   }

}
